pub enum Error {
NotEnoughInputData,
TooMuchOutputData,
TooMuchInputData,
Io(Error),
}Expand description
General error used in packbit extraction
Variants
NotEnoughInputData
Input does not provide enough data to fill the requested size
TooMuchOutputData
The output buffer is too small or the decoded size does not fit into the requested size
TooMuchInputData
Input has additional unread data left after decoding
Io(Error)
An operation (like read or seek) on the underlying reader has failed