Operation

Enum Operation 

pub enum Operation {
    Literal(u8),
    Repeat(u8, u16),
}
Describes an unpacking operation, that can be fed additional data to recieved an output byte and the next operation

Variants



Literal(u8)

We’re in the middle of returning literal bytes



Repeat(u8, u16)

The unpacker will emit .1 more repetitions of byte .0

Implementations

Source

impl Operation

pub fn new() -> Self

Create a new empty operation, advancing (Operation::advance) it will read an entire new operation from the underlying reader.

pub fn advance<T: Read>( &self, reader: &mut T, ) -> Result<(u8, Self), OperationError>

Produce a byte and return next state of the decoder at the same time

If self was already completed, this function will try to fetch the next command from the underlying reader. Otherwise it will just perform the repetition, or read the next literal.

pub fn is_completed(&self) -> bool

Determines if the current operation has been advanced to completion.