pub enum OperationError {
InsufficientInput(Command),
UnexpectedEof,
Io(Error),
}Expand description
Variants
InsufficientInput(Command)
The input stream ended, before the operation could complete.
If more data becomes available, the provided command can be used to continue unpacking where we left off.
UnexpectedEof
The input stream ended with no unfinished command, this could be a good place to stop unpacking if enough input bytes have been read or enough output bytes provided.
Io(Error)
An operation like read or seek on the underlying underlying reader has failed.