pub struct Reader<T: Read> { /* private fields */ }Expand description
Wraps an input stream to provide transparent access to unpacked PackBit bytes
Implementations
Sourceimpl<T: Read> Reader<T>
impl<T: Read> Reader<T>
Sourcepub fn with_max_output(inner: T, max_output: u64) -> Self
pub fn with_max_output(inner: T, max_output: u64) -> Self
Create new reader with a maximum output size
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Unwrap the reader, destroying it’s internal state and returning the original reader
Note that the current position may have been changed since the reader was wrapped.